# cstrike/addons/eventscripts/_libs/python/inputlib.py
import es, gamethread

# Where we store all of our users data
input_userids = {}

# Our input checker class that handles everything
class InputChecker:

        def __init__(self, userid):
                self.userid = int(userid)

        # Lets other scripts register a chatbox input filter
        # The *args means that you can use as little or much args as you want, so you could do chatbox(1, 2, 3, 4, 5, 6, 7, Cool, chatbox(1, 2, 3, 4) or even just chatbox(1, 2, 3)
        def chatbox(self, timeout, function, inputname, *args):
                # Cancel the old input checker on a user if they already have one
                if self.userid in input_userids:
                        # Stop the input by name
                        self.stop_input(input_userids[self.userid]['name'])
                        # Kinda encourage people to use InputChecker(userid).has_input() tsk tsk tsk, good practice :/
                        es.dbgmsg(0, 'Inputlib: Overriding input')
                # Set a key in input_userids to info that the scripter has specified,
                input_userids[self.userid] = {'function': function, 'name': inputname, 'args': args if (len(args) > 1 or not args) else args[0]}
                # Set a timeout for the person to input something
                gamethread.delayedname(timeout, inputname + '_%s'%self.userid, self.stop_input, inputname)

        def __chatinput__(self, input, teamonly):
                if self.userid in input_userids:
                        # We're assigning args to input_userids[self.userid] because we're about to delete input_userids[self.userid]
                        # Also, I'm pretty lazy Smile
                        # This will also stop a few dbgmsgs if the function that the script calls calls InputChecker(userid).chatbox again
                        args = input_userids[self.userid]
                        # Stop debug messages if the script calls InputChecker(userid).chatbox
                        self.stop_input(args['name'])
                        # Just an optional feature here, if args['args'] is true, that means that the scripter has specified that they want to have some custom args
                        # Passed on to their function, so they don't have to use a bunch of globals and such
                        if not type(args['function']) == str:
                                if args['args']:
                                        args['function'](self.userid, input.replace('"', ''), args['name'], args['args'])
                                # Otherwise, just normally call the function
                                else:
                                        args['function'](self.userid, input.replace('"', ''), args['name'])
                        else:
                                es.cexec(self.userid, args['function'] + ' ' + input.replace('"', ''))
                        # Make the text not visible
                        return None, None, None
                # Make the text visible, if the person doesn't have an input checker on them
                return self.userid, input, teamonly

        def stop_input(self, inputname):
                # Make sure that the person has an input running, so no errors are thrown
                if not self.userid in input_userids:
                        return
                # Cancel the delay to stop_input just incase stop_input was called manually by a script, or a person typed something in in time
                # And then another one with the same input name isn't registerd and then cancled really fast.
                gamethread.cancelDelayed(inputname + '_%s'%self.userid)
                # Delete the userid from input_userids
                del input_userids[self.userid]

        def has_input(self):
                return self.userid in input_userids

# Check to see if a person has a chat input going on
def _check_chat_input(userid, args, teamonly):
        return InputChecker(userid).__chatinput__(args, teamonly)

# Whenever a script imports inputlib, it'll make sure that there's a say filter present
es.addons.registerSayFilter(_check_chat_input) 